==> mx-codecs_19.7.tar.xz: mx-codecs-19.7/translations/mx-codecs_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Unable to get exclusive lock</source>
        <translation>無法獨佔鎖定</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>系統上已經有別的軟體管理工具（例如 Synaptic 或 apt-get）在運作。請先關閉該程式。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You must run this program as root.</source>
        <translation>本程式必須以 root 身份來執行。</translation>
    </message>
</context>
<context>
    <name>mxcodecs</name>
    <message>
        <location filename="../mxcodecs.ui" line="14"/>
        <source>MX Codecs Installer</source>
        <translation>MX 影音編碼安裝工具</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;本程式讓你可以安裝某些限制性的編碼，以使用進階的影音功能。&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;在某些地區，這些編碼的流通受到限制；使用者必須遵守當地的法規。&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;下載這些編碼，你願承擔法律責任嗎？&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>正在下載編碼檔案</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="94"/>
        <source>Cancel any changes then quit</source>
        <translation>取消所有更動，然後退出</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="97"/>
        <location filename="../mxcodecs.cpp" line="270"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="105"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="118"/>
        <source>Apply any changes then quit</source>
        <translation>採用所有更動，然後退出</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="121"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="177"/>
        <source>About this application</source>
        <translation>關於本程式</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="180"/>
        <source>About...</source>
        <translation>關於……</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="188"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="217"/>
        <source>Display help </source>
        <translation>顯示說明</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="220"/>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="228"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="103"/>
        <location filename="../mxcodecs.cpp" line="110"/>
        <location filename="../mxcodecs.cpp" line="118"/>
        <location filename="../mxcodecs.cpp" line="126"/>
        <location filename="../mxcodecs.cpp" line="135"/>
        <location filename="../mxcodecs.cpp" line="142"/>
        <location filename="../mxcodecs.cpp" line="151"/>
        <location filename="../mxcodecs.cpp" line="159"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;執行命令……&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="106"/>
        <location filename="../mxcodecs.cpp" line="122"/>
        <location filename="../mxcodecs.cpp" line="129"/>
        <location filename="../mxcodecs.cpp" line="138"/>
        <location filename="../mxcodecs.cpp" line="144"/>
        <location filename="../mxcodecs.cpp" line="155"/>
        <location filename="../mxcodecs.cpp" line="162"/>
        <location filename="../mxcodecs.cpp" line="194"/>
        <location filename="../mxcodecs.cpp" line="247"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="107"/>
        <location filename="../mxcodecs.cpp" line="123"/>
        <location filename="../mxcodecs.cpp" line="139"/>
        <location filename="../mxcodecs.cpp" line="156"/>
        <source>Cannot connect to the download site</source>
        <translation>無法連接下載的站臺</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="113"/>
        <location filename="../mxcodecs.cpp" line="130"/>
        <location filename="../mxcodecs.cpp" line="145"/>
        <location filename="../mxcodecs.cpp" line="163"/>
        <source>Error downloading %1</source>
        <translation>下載 %1 時發生錯誤</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="168"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;下載完成。&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="190"/>
        <source>Installing downloaded files</source>
        <translation>正在安裝下載的檔案</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="195"/>
        <source>No downloaded *.debs files found.</source>
        <translation>找不到下載的 *.debs 檔。</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="208"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;正在安裝……&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="222"/>
        <source>Error installing %1</source>
        <translation>安裝 %1 時發生錯誤</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="226"/>
        <source>Fix missing dependencies...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="228"/>
        <source>Error running &apos;apt-get -fm install&apos; command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="240"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;安裝程序已完成&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="243"/>
        <source>Finished</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="244"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>編碼已順利下載並安裝。</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="248"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>程序結束。安裝時發生錯誤。</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="263"/>
        <source>About MX Codecs</source>
        <translation>關於 MX 影音編碼</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="264"/>
        <source>MX Codecs</source>
        <translation>MX 影音編碼</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="264"/>
        <source>Version: </source>
        <translation>版本：</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="266"/>
        <source>Simple codecs downloader for MX Linux</source>
        <translation>MX Linux 的簡易編碼下載工具</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="267"/>
        <source>Copyright (c) MX Linux</source>
        <translation>版權所有 (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="268"/>
        <source>License</source>
        <translation>授權條款</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="269"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="285"/>
        <source>&amp;Close</source>
        <translation>關閉（&amp;C）</translation>
    </message>
</context>
</TS>

==> mx-codecs_19.9.tar.xz: mx-codecs-19.9/translations/mx-codecs_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Unable to get exclusive lock</source>
        <translation>無法獨佔鎖定</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>系統上已經有別的軟體管理工具（例如 Synaptic 或 apt-get）在運作。請先關閉該程式。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You must run this program as root.</source>
        <translation>本程式必須以 root 身份來執行。</translation>
    </message>
</context>
<context>
    <name>mxcodecs</name>
    <message>
        <location filename="../mxcodecs.ui" line="14"/>
        <source>MX Codecs Installer</source>
        <translation>MX 影音編碼安裝工具</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;本程式讓你可以安裝某些限制性的編碼，以使用進階的影音功能。&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;在某些地區，這些編碼的流通受到限制；使用者必須遵守當地的法規。&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;下載這些編碼，你願承擔法律責任嗎？&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>正在下載編碼檔案</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="94"/>
        <source>Cancel any changes then quit</source>
        <translation>取消所有更動，然後退出</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="97"/>
        <location filename="../mxcodecs.cpp" line="267"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="105"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="118"/>
        <source>Apply any changes then quit</source>
        <translation>採用所有更動，然後退出</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="121"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="177"/>
        <source>About this application</source>
        <translation>關於本程式</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="180"/>
        <source>About...</source>
        <translation>關於……</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="188"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="217"/>
        <source>Display help </source>
        <translation>顯示說明</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="220"/>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="228"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="104"/>
        <location filename="../mxcodecs.cpp" line="111"/>
        <location filename="../mxcodecs.cpp" line="119"/>
        <location filename="../mxcodecs.cpp" line="127"/>
        <location filename="../mxcodecs.cpp" line="136"/>
        <location filename="../mxcodecs.cpp" line="143"/>
        <location filename="../mxcodecs.cpp" line="152"/>
        <location filename="../mxcodecs.cpp" line="160"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;執行命令……&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="107"/>
        <location filename="../mxcodecs.cpp" line="123"/>
        <location filename="../mxcodecs.cpp" line="130"/>
        <location filename="../mxcodecs.cpp" line="139"/>
        <location filename="../mxcodecs.cpp" line="145"/>
        <location filename="../mxcodecs.cpp" line="156"/>
        <location filename="../mxcodecs.cpp" line="163"/>
        <location filename="../mxcodecs.cpp" line="192"/>
        <location filename="../mxcodecs.cpp" line="245"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="108"/>
        <location filename="../mxcodecs.cpp" line="124"/>
        <location filename="../mxcodecs.cpp" line="140"/>
        <location filename="../mxcodecs.cpp" line="157"/>
        <source>Cannot connect to the download site</source>
        <translation>無法連接下載的站臺</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="114"/>
        <location filename="../mxcodecs.cpp" line="131"/>
        <location filename="../mxcodecs.cpp" line="146"/>
        <location filename="../mxcodecs.cpp" line="164"/>
        <source>Error downloading %1</source>
        <translation>下載 %1 時發生錯誤</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="169"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;下載完成。&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="188"/>
        <source>Installing downloaded files</source>
        <translation>正在安裝下載的檔案</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="193"/>
        <source>No downloaded *.debs files found.</source>
        <translation>找不到下載的 *.debs 檔。</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="206"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;正在安裝……&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="219"/>
        <source>Error installing %1</source>
        <translation>安裝 %1 時發生錯誤</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="223"/>
        <source>Fix missing dependencies...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="225"/>
        <source>Error running %1 command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="237"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;安裝程序已完成&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="241"/>
        <source>Finished</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="242"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>編碼已順利下載並安裝。</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="246"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>程序結束。安裝時發生錯誤。</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="260"/>
        <source>About MX Codecs</source>
        <translation>關於 MX 影音編碼</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="261"/>
        <source>MX Codecs</source>
        <translation>MX 影音編碼</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="261"/>
        <source>Version: </source>
        <translation>版本：</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="263"/>
        <source>Simple codecs downloader for MX Linux</source>
        <translation>MX Linux 的簡易編碼下載工具</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="264"/>
        <source>Copyright (c) MX Linux</source>
        <translation>版權所有 (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="265"/>
        <source>License</source>
        <translation>授權條款</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="266"/>
        <location filename="../mxcodecs.cpp" line="276"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="283"/>
        <source>&amp;Close</source>
        <translation>關閉（&amp;C）</translation>
    </message>
</context>
</TS>
